﻿using System.Collections.Generic;
using Ozeki.VoIP;

namespace Web2SIPServer
{
        /// <summary>
    /// SIP account container class.
    /// </summary>
    class SIPAccountPool
    {
        Queue<SIPAccount> _sipAccounts;

        /// <summary>
        /// Create a new instace of SIPAccountPool.
        /// </summary>
        public SIPAccountPool()
        {
            _sipAccounts = new Queue<SIPAccount>();
        }

        /// <summary>
        /// Gets the next free SIP account.
        /// </summary>
        /// <returns></returns>
        public SIPAccount GetSIPAccount()
        {
            SIPAccount sipAccount;
            lock (_sipAccounts)
            {
                if (_sipAccounts.Count > 0)
                {
                    sipAccount = _sipAccounts.Dequeue();
                    return sipAccount;
                }
            }
            return null;
        }

        /// <summary>
        /// Adds a SIP account to the accounts queue.
        /// </summary>
        /// <param name="sipAccount"></param>
        public void AddSIPAcount(SIPAccount sipAccount)
        {
            lock (_sipAccounts)
            {
                _sipAccounts.Enqueue(sipAccount);    
            }
            
        }
    }
}
